@@ -1,5 +1,5 @@
 package Class::constr ;
-$VERSION = 1.73 ;
+$VERSION = 1.74 ;
 
 # This file uses the "Perlish" coding style
 # please read http://perl.4pro.net/perlish_coding_style.html
@@ -39,7 +39,8 @@ $VERSION = 1.73 ;
               }
            ; if ( $$constr{init} )
               { foreach my $m ( @{$$constr{init}} )
-                 { $s->$m(@_)
+                 { last unless $s                    # thanks to Vince
+                 ; $s->$m(@_)
                  }
               }
            ; $s
@@ -56,9 +57,9 @@ __END__
 
 Class::constr - Pragma to implement constructor methods
 
-=head1 VERSION 1.73
+=head1 VERSION 1.74
 
-Included in OOTools 1.73 distribution.
+Included in OOTools 1.74 distribution.
 
 The latest versions changes are reported in the F<Changes> file in this distribution.
 
@@ -109,8 +110,6 @@ From the directory where this file is located, type:
     make test
     make install
 
-B<Note>: The installation of this module runs an automatic version check connection which will warn you in case a newer version is available: please don't use old versions, because I can give you full support only for current versions. Besides, since CPAN does not provide any download statistic to the authors, this check allows me also to keep my own installation counter. Version checking is transparent to regular users, while CPAN testers should skip it by running the Makefile.PL with NO_VERSION_CHECK=1.
-
 =back
 
 =head1 SYNOPSIS
@@ -198,4 +197,3 @@ All Rights Reserved. This module is free software. It may be used, redistributed
 =head1 CREDITS
 
 Thanks to Juerd Waalboer (http://search.cpan.org/author/JUERD) that with its I<Attribute::Property> inspired the creation of this distribution.
-
